summaryrefslogtreecommitdiffstats
path: root/perl-install/standalone.pm
diff options
context:
space:
mode:
Diffstat (limited to 'perl-install/standalone.pm')
-rw-r--r--perl-install/standalone.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/perl-install/standalone.pm b/perl-install/standalone.pm
index 7e86c1d7a..c20381911 100644
--- a/perl-install/standalone.pm
+++ b/perl-install/standalone.pm
@@ -194,8 +194,8 @@ sub bug_handler {
# we want the full backtrace:
$error .= common::backtrace() if $error;
my $progname = $0;
- # do not loop if drakbug crashes:
- if ($progname =~ /drakbug/) {
+ # do not loop if drakbug crashes and do not complain about wizcancel:
+ if ($progname =~ /drakbug/ || $error =~ /wizcancel/) {
warn $error;
exit(1);
}